/*
 * dac.c
 *
 *  Created on: Feb 13, 2012
 *      Author: Kurt Snieckus
 *
 *      Functions to configure and use the DAC
 */


#include <msp430.h>
#include <msp430x26x.h>
#include "dac.h"

#define DAC_MAX 0xFFF

void dac_init(void) {
	// Initialize DAC registers on MSP430F2616 on R01 PCB

	// DAC0 -> P6.6
	// DAC1 -> P6.5

	// not using the internal ref.
	//ADC12CTL0 = REF2_5V + REFON;              // Internal 2.5V ref on

	__delay_cycles(136000);					// Allow ref to settle?!

	// ~DAC12OPS:  Use P6.6 and P6.7
	// DAC12SREF_0: Use Vref+
	// ~DAC12RES: 12-Bit mode
	// DAC12LSEL_0: DAC12 latch loads when DAC12_xDAT written (DAC12ENC is ignored)
	// ~DAC12CALON: Initiate Calibration
	// DAC12IR: DAC12 full-scale output = 1x reference voltage
	// DAC12AMP_5: DAC12 amplifier setting -> Medium speed/current for input and output
	// ~DAC12DF: Straight Binary
	// ~DAC12IE: Interrupt Disable
	// ~DAC12IFG: No Interrupt Flag
	// DAC12ENC: Enable DAC12
	// ~DAC12GRP: DAC 12 not grouped

	DAC12_0CTL = DAC12IR + DAC12SREF_2 + DAC12AMP_5 + DAC12ENC;
	DAC12_1CTL = DAC12IR + DAC12SREF_2 + DAC12AMP_5 + DAC12ENC;

	// Do a calibration?!
	//DAC12_0CTL |= DAC12CALON;  // Start cal on channel 0
	//while (DAC12_0CTL & DAC12CALON); // Wait for cal to complete

	//DAC12_1CTL |= DAC12CALON;  // Start cal on channel 1
	//while (DAC12_1CTL & DAC12CALON); // Wait for cal to complete

	// IMPORTANTE!
	// Set DAC output to highest value because that is the default for the converter.
	dac_write(0, 0xeFF);


}

void dac_write(unsigned char channel, unsigned int out) {

	if (out > DAC_MAX) {
		out = DAC_MAX;
	}

	if (channel == 0) {
		DAC12_0DAT = out;
	} else if (channel == 1) {
		DAC12_1DAT = out;
	}
}

